//  Copyright (C) 2010 Ben Asselstine
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU Library General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
//  02110-1301, USA.

#ifndef TAPIOCA_GALLERY_DIALOG_H
#define TAPIOCA_GALLERY_DIALOG_H

#include <gtkmm.h>
#include <gconfmm.h>
#include "gallery.h"
#include "item-tagging-widget.h"
using namespace Tapioca;

class GalleryDialog: public Gtk::Dialog
{
 public:
    virtual ~GalleryDialog();

    GalleryDialog(BaseObjectType* baseObject, const Glib::RefPtr<Gtk::Builder>& xml);

    static GalleryDialog* create(Tapioca::Gallery *g, const Tapioca::Gallery *original, bool readonly = false);
 private:
    Tapioca::Gallery *gallery;
    const Tapioca::Gallery *original;
    bool readonly;
    Gtk::Entry *title_entry;
    Gtk::TextView *description_textview;
    Gtk::Image *thumbnail_image;
    Gtk::Label *doc_count_label;
    Gtk::SpinButton *lat_spinbutton;
    Gtk::SpinButton *lon_spinbutton;
    Gtk::VBox *item_tagging_widget_container;
    Tapioca::ItemTaggingWidget *item_tagging_widget;
    Gtk::Label *title_label;
    Gtk::Label *description_label;
    Gtk::Label *latitude_label;
    Gtk::Label *longitude_label;
    Gtk::CheckButton *private_audience_checkbutton;

    //callbacks
    void on_title_changed();
    void on_description_changed();
    void on_lat_changed();
    void on_lon_changed();
    void on_response_received(int response);
    void on_private_audience_toggled();
    void on_dialog_loaded(Tapioca::Gallery *g, const Tapioca::Gallery *orig, 
                          bool uneditable);
};

#endif // TAPIOCA_GALLERY_DIALOG_H
